import java.util.*;
import java.io.*;

public class parallelepipeds_mp_java {
    FastScanner in;
    PrintWriter out;

    static final int IINF = 0x3f3f3f3f;

    static class Flow {
        static class Edge {
            int nv, f, c;
            Edge p;

            Edge(int nnv, int nc) {
                nv = nnv;
                c = nc;
                f = 0;
            }
        }

        int n;
        ArrayList<Edge> e[];
        int dist[];
        int pos[];
        int q[];

        @SuppressWarnings("unchecked")
        Flow(int nn) {
            n = nn;
            e = new ArrayList[n];
            for (int i = 0; i < n; ++i)
                e[i] = new ArrayList<Edge>();
            dist = new int[n];
            pos = new int[n];
            q = new int[n];
        }

        void addEdge(int x, int y, int c) {
            Edge e1 = new Edge(y, c);
            Edge e2 = new Edge(x, 0);
            e1.p = e2;
            e2.p = e1;
            e[x].add(e1);
            e[y].add(e2);
        }

        int dfs(int v, int t, int scale, int cur) {
            if (v == t)
                return cur;
            while (pos[v] != e[v].size()) {
                Edge ce = e[v].get(pos[v]);
                int nv = ce.nv;
                int cf = ce.c - ce.f;
                if (dist[nv] - dist[v] != 1 || cf < scale) {
                    ++pos[v];
                    continue;
                }
                int nf = dfs(nv, t, scale, Math.min(cur, cf));
                if (nf == 0) {
                    ++pos[v];
                    continue;
                }
                ce.f += nf;
                ce.p.f -= nf;
                return nf;
            }
            return 0;
        }

        boolean bfs(int s, int t, int scale) {
            int qs = 1;
            q[0] = s;
            Arrays.fill(dist, IINF);
            dist[s] = 0;
            for (int i = 0; i < qs; ++i) {
                int v = q[i];
                int cd = dist[v];
                for (Edge ce : e[v]) {
                    int cf = ce.c - ce.f;
                    int nv = ce.nv;
                    if (cf < scale || dist[nv] != IINF)
                        continue;
                    dist[nv] = cd + 1;
                    if (nv == t)
                        return true;
                    q[qs++] = nv;
                }
            }
            return false;
        }

        int maxflowScale(int s, int t, int scale) {
            int ans = 0;
            while (bfs(s, t, scale)) {
                while (true) {
                    Arrays.fill(pos, 0);
                    int f = dfs(s, t, scale, IINF);
                    if (f == 0)
                        break;
                    ans += f;
                }
            }
            return ans;
        }

        int maxflow(int s, int t) {
            int ans = 0;
            for (int scale = 1 << 30; scale > 0; scale >>= 1)
                ans += maxflowScale(s, t, scale);
            return ans;
        }
    }

    @SuppressWarnings("unchecked")
    public void solve() throws IOException {
        int n = in.nextInt();
        int k = in.nextInt();
        n /= 2;
        int a[][] = new int[n*2][k];
        int coords[][] = new int[k][n*2];

        for (int i = 0; i < n*2; ++i) {
            for (int j = 0; j < k; ++j) {
                a[i][j] = in.nextInt();
                coords[j][i] = a[i][j];
            }
        }

        int mid[] = new int[k];
        for (int i = 0; i < k; ++i) {
            int c[] = coords[i];
            Arrays.sort(c);
            mid[i] = c[n - 1] + c[n];
        }

        int p3[] = new int[k + 1];
        p3[0] = 1;
        for (int i = 1; i <= k; ++i)
            p3[i] = p3[i - 1] * 3;

        ArrayList<Integer> buckets[] = new ArrayList[p3[k]];
        for (int i = 0; i < p3[k]; ++i)
            buckets[i] = new ArrayList<Integer>();
        for (int i = 0; i < n*2; ++i) {
            int b = 0;
            for (int j = 0; j < k; ++j) {
                int x;
                if (a[i][j] * 2 < mid[j])
                    x = 0;
                else if (a[i][j] * 2 > mid[j])
                    x = 2;
                else
                    x = 1;
                b += x * p3[j];
            }
            buckets[b].add(i);
        }

        Flow flow = new Flow(p3[k] + 2);
        int vs = p3[k];
        int vt = p3[k] + 1;
        
        for (int i = 0; i < p3[k]; ++i) {
            int ci = i;
            int c0 = ci % 3;
            if (c0 == 1) {
                assert buckets[i].isEmpty();
                continue;
            }
            ci /= 3;
            boolean was = false;
            for (int j = 1; j < k; ++j) {
                int x = ci % 3;
                ci /= 3;
                if (x == 1) {
                    was = true;
                    if (c0 == 0) {
                        flow.addEdge(i, i - p3[j], n);
                        flow.addEdge(i, i + p3[j], n);
                    } else {
                        flow.addEdge(i - p3[j], i, n);
                        flow.addEdge(i + p3[j], i, n);
                    }
                    break;
                }
            }
            if (!was && c0 == 0)
                flow.addEdge(i, p3[k] - 1 - i, n);
            if (c0 == 0)
                flow.addEdge(vs, i, buckets[i].size());
            else
                flow.addEdge(i, vt, buckets[i].size());
        }
        
        if (flow.maxflow(vs, vt) != n) {
            out.println("NO");
            return;
        }

        out.println("YES");
        for (int iter = 0; iter < n; ++iter) {
            int v = vs;
            int v1 = -1, v2 = -1;
            while (v != vt) {
                if (v1 == -1 && v != vs)
                    v1 = v;
                v2 = v;
                boolean was = false;
                for (Flow.Edge ce : flow.e[v]) {
                    if (ce.f > 0) {
                        was = true;
                        --ce.f;
                        ++ce.p.f;
                        v = ce.nv;
                        break;
                    }
                }
                assert was;
            }
            assert !buckets[v1].isEmpty();
            assert !buckets[v2].isEmpty();
            out.print(buckets[v1].get(buckets[v1].size() - 1) + 1);
            out.print(" ");
            out.println(buckets[v2].get(buckets[v2].size() - 1) + 1);
            buckets[v1].remove(buckets[v1].size() - 1);
            buckets[v2].remove(buckets[v2].size() - 1);
        }
    }

    public void run() {
        try {
            in = new FastScanner(System.in);
            out = new PrintWriter(System.out);

            solve();

            out.close();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    class FastScanner {
        BufferedReader br;
        StringTokenizer st;

        FastScanner(InputStream f) {
            br = new BufferedReader(new InputStreamReader(f));
        }

        String next() {
            while (st == null || !st.hasMoreTokens()) {
                try {
                    st = new StringTokenizer(br.readLine());
                } catch (IOException e) {
                    e.printStackTrace();
                }
            }
            return st.nextToken();
        }

        int nextInt() {
            return Integer.parseInt(next());
        }

        long nextLong() {
            return Long.parseLong(next());
        }
    }

    public static void main(String[] arg) {
        new parallelepipeds_mp_java().run();
    }
}

